.. peewee documentation master file, created by
   sphinx-quickstart on Thu Nov 25 21:20:29 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

peewee
======

* a small, expressive orm
* written in python (2.6+, 3.2+)

.. image:: postgresql.png
    :target: peewee/cookbook.html#using-with-postgresql
    :alt: postgresql

.. image:: mysql.png
    :target: peewee/cookbook.html#using-with-mysql
    :alt: mysql

.. image:: sqlite.png
    :target: peewee/cookbook.html#using-with-sqlite
    :alt: sqlite


See notes on :ref:`notes on upgrading and changes from 1.0 <upgrading>`

Contents:
---------

.. toctree::
   :maxdepth: 2
   :glob:

   peewee/installation
   peewee/quickstart
   peewee/example
   peewee/cookbook
   peewee/models
   peewee/querying
   peewee/database
   peewee/api
   peewee/playhouse
   peewee/upgrading

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
